==> prime_sdk_py-0.3.1-py3-none-any.whl: prime_sdk/get_allocation_by_id.py <==
# Copyright 2024-present Coinbase Global, Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
#  limitations under the License.

from dataclasses import dataclass
from typing import List
from prime_sdk.base_response import BaseResponse
from prime_sdk.client import Client
from prime_sdk.credentials import Credentials


@dataclass
class GetAllocationByIdRequest:
    portfolio_id: str
    allocation_id: str
    allowed_status_codes: List[int] = None


@dataclass
class GetAllocationByIdResponse(BaseResponse):
    request: GetAllocationByIdRequest


class PrimeClient:
    def __init__(self, credentials: Credentials):
        self.client = Client(credentials)
        
    def get_allocation_by_id(self, request: GetAllocationByIdRequest) -> GetAllocationByIdResponse:
        path = f"/portfolios/{request.portfolio_id}/allocations/{request.allocation_id}"
        response = self.client.request("GET", path, query=None, allowed_status_codes=request.allowed_status_codes)
        return GetAllocationByIdResponse(response.json(), request)

==> prime_sdk_py-0.4.0-py3-none-any.whl: prime_sdk/get_allocation_by_id.py <==
# Copyright 2024-present Coinbase Global, Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from dataclasses import dataclass
from typing import List, Optional
from prime_sdk.base_response import BaseResponse
from prime_sdk.client import Client
from prime_sdk.credentials import Credentials
from prime_sdk.model import Allocation


@dataclass
class GetAllocationByIdRequest:
    portfolio_id: str
    allocation_id: str
    allowed_status_codes: Optional[List[int]] = None


@dataclass
class GetAllocationByIdResponse(BaseResponse):
    allocation: Allocation = None


class PrimeClient:
    def __init__(self, credentials: Credentials):
        self.client = Client(credentials)
        
    def get_allocation_by_id(self, request: GetAllocationByIdRequest) -> GetAllocationByIdResponse:
        path = f"/portfolios/{request.portfolio_id}/allocations/{request.allocation_id}"
        response = self.client.request("GET", path, allowed_status_codes=request.allowed_status_codes)
        return GetAllocationByIdResponse(response.json())
